@@ -88,14 +88,12 @@ fn command(
 
     df.as_ref()
         .to_dummies(None, drop_first)
-        .map_err(|e| {
-            ShellError::GenericError(
-                "Error calculating dummies".into(),
-                e.to_string(),
-                Some(call.head),
-                Some("The only allowed column types for dummies are String or Int".into()),
-                Vec::new(),
-            )
+        .map_err(|e| ShellError::GenericError {
+            error: "Error calculating dummies".into(),
+            msg: e.to_string(),
+            span: Some(call.head),
+            help: Some("The only allowed column types for dummies are String or Int".into()),
+            inner: vec![],
         })
         .map(|df| PipelineData::Value(NuDataFrame::dataframe_into_value(df, call.head), None))
 }
