@@ -68,13 +68,13 @@ pub(super) fn compute_between_series(
                     res.rename(&name);
                     NuDataFrame::series_to_value(res, operation_span)
                 }
-                Err(e) => Err(ShellError::GenericError(
-                    "Division error".into(),
-                    e.to_string(),
-                    Some(right.span()),
-                    None,
-                    Vec::new(),
-                )),
+                Err(e) => Err(ShellError::GenericError {
+                    error: "Division error".into(),
+                    msg: e.to_string(),
+                    span: Some(right.span()),
+                    help: None,
+                    inner: vec![],
+                }),
             }
         }
         Operator::Comparison(Comparison::Equal) => {
@@ -119,13 +119,13 @@ pub(super) fn compute_between_series(
                         res.rename(&name);
                         NuDataFrame::series_to_value(res, operation_span)
                     }
-                    _ => Err(ShellError::GenericError(
-                        "Incompatible types".into(),
-                        "unable to cast to boolean".into(),
-                        Some(right.span()),
-                        None,
-                        Vec::new(),
-                    )),
+                    _ => Err(ShellError::GenericError {
+                        error: "Incompatible types".into(),
+                        msg: "unable to cast to boolean".into(),
+                        span: Some(right.span()),
+                        help: None,
+                        inner: vec![],
+                    }),
                 }
             }
             _ => Err(ShellError::IncompatibleParametersSingle {
@@ -148,13 +148,13 @@ pub(super) fn compute_between_series(
                         res.rename(&name);
                         NuDataFrame::series_to_value(res, operation_span)
                     }
-                    _ => Err(ShellError::GenericError(
-                        "Incompatible types".into(),
-                        "unable to cast to boolean".into(),
-                        Some(right.span()),
-                        None,
-                        Vec::new(),
-                    )),
+                    _ => Err(ShellError::GenericError {
+                        error: "Incompatible types".into(),
+                        msg: "unable to cast to boolean".into(),
+                        span: Some(right.span()),
+                        help: None,
+                        inner: vec![],
+                    }),
                 }
             }
             _ => Err(ShellError::IncompatibleParametersSingle {
@@ -186,14 +186,12 @@ where
     F: Fn(&'s Series, &'s Series) -> Result<ChunkedArray<BooleanType>, PolarsError>,
 {
     let mut res = f(lhs, rhs)
-        .map_err(|e| {
-            ShellError::GenericError(
-                "Equality error".into(),
-                e.to_string(),
-                Some(span),
-                None,
-                Vec::new(),
-            )
+        .map_err(|e| ShellError::GenericError {
+            error: "Equality error".into(),
+            msg: e.to_string(),
+            span: Some(span),
+            help: None,
+            inner: vec![],
         })?
         .into_series();
 
@@ -458,29 +456,29 @@ where
                     let casted = series.i64();
                     compute_casted_i64(casted, val, f, span)
                 }
-                Err(e) => Err(ShellError::GenericError(
-                    "Unable to cast to i64".into(),
-                    e.to_string(),
-                    Some(span),
-                    None,
-                    Vec::new(),
-                )),
+                Err(e) => Err(ShellError::GenericError {
+                    error: "Unable to cast to i64".into(),
+                    msg: e.to_string(),
+                    span: Some(span),
+                    help: None,
+                    inner: vec![],
+                }),
             }
         }
         DataType::Int64 => {
             let casted = series.i64();
             compute_casted_i64(casted, val, f, span)
         }
-        _ => Err(ShellError::GenericError(
-            "Incorrect type".into(),
-            format!(
+        _ => Err(ShellError::GenericError {
+            error: "Incorrect type".into(),
+            msg: format!(
                 "Series of type {} can not be used for operations with an i64 value",
                 series.dtype()
             ),
-            Some(span),
-            None,
-            Vec::new(),
-        )),
+            span: Some(span),
+            help: None,
+            inner: vec![],
+        }),
     }
 }
 
@@ -499,13 +497,13 @@ where
             let res = res.into_series();
             NuDataFrame::series_to_value(res, span)
         }
-        Err(e) => Err(ShellError::GenericError(
-            "Unable to cast to i64".into(),
-            e.to_string(),
-            Some(span),
-            None,
-            Vec::new(),
-        )),
+        Err(e) => Err(ShellError::GenericError {
+            error: "Unable to cast to i64".into(),
+            msg: e.to_string(),
+            span: Some(span),
+            help: None,
+            inner: vec![],
+        }),
     }
 }
 
@@ -522,29 +520,29 @@ where
                     let casted = series.f64();
                     compute_casted_f64(casted, val, f, span)
                 }
-                Err(e) => Err(ShellError::GenericError(
-                    "Unable to cast to f64".into(),
-                    e.to_string(),
-                    Some(span),
-                    None,
-                    Vec::new(),
-                )),
+                Err(e) => Err(ShellError::GenericError {
+                    error: "Unable to cast to f64".into(),
+                    msg: e.to_string(),
+                    span: Some(span),
+                    help: None,
+                    inner: vec![],
+                }),
             }
         }
         DataType::Float64 => {
             let casted = series.f64();
             compute_casted_f64(casted, val, f, span)
         }
-        _ => Err(ShellError::GenericError(
-            "Incorrect type".into(),
-            format!(
+        _ => Err(ShellError::GenericError {
+            error: "Incorrect type".into(),
+            msg: format!(
                 "Series of type {} can not be used for operations with a float value",
                 series.dtype()
             ),
-            Some(span),
-            None,
-            Vec::new(),
-        )),
+            span: Some(span),
+            help: None,
+            inner: vec![],
+        }),
     }
 }
 
@@ -563,13 +561,13 @@ where
             let res = res.into_series();
             NuDataFrame::series_to_value(res, span)
         }
-        Err(e) => Err(ShellError::GenericError(
-            "Unable to cast to f64".into(),
-            e.to_string(),
-            Some(span),
-            None,
-            Vec::new(),
-        )),
+        Err(e) => Err(ShellError::GenericError {
+            error: "Unable to cast to f64".into(),
+            msg: e.to_string(),
+            span: Some(span),
+            help: None,
+            inner: vec![],
+        }),
     }
 }
 
@@ -586,13 +584,13 @@ where
                     let casted = series.i64();
                     compare_casted_i64(casted, val, f, span)
                 }
-                Err(e) => Err(ShellError::GenericError(
-                    "Unable to cast to f64".into(),
-                    e.to_string(),
-                    Some(span),
-                    None,
-                    Vec::new(),
-                )),
+                Err(e) => Err(ShellError::GenericError {
+                    error: "Unable to cast to f64".into(),
+                    msg: e.to_string(),
+                    span: Some(span),
+                    help: None,
+                    inner: vec![],
+                }),
             }
         }
         DataType::Date => {
@@ -607,29 +605,29 @@ where
                         .expect("already checked for casting");
                     compare_casted_i64(Ok(&casted), val, f, span)
                 }
-                Err(e) => Err(ShellError::GenericError(
-                    "Unable to cast to f64".into(),
-                    e.to_string(),
-                    Some(span),
-                    None,
-                    Vec::new(),
-                )),
+                Err(e) => Err(ShellError::GenericError {
+                    error: "Unable to cast to f64".into(),
+                    msg: e.to_string(),
+                    span: Some(span),
+                    help: None,
+                    inner: vec![],
+                }),
             }
         }
         DataType::Int64 => {
             let casted = series.i64();
             compare_casted_i64(casted, val, f, span)
         }
-        _ => Err(ShellError::GenericError(
-            "Incorrect type".into(),
-            format!(
+        _ => Err(ShellError::GenericError {
+            error: "Incorrect type".into(),
+            msg: format!(
                 "Series of type {} can not be used for operations with an i64 value",
                 series.dtype()
             ),
-            Some(span),
-            None,
-            Vec::new(),
-        )),
+            span: Some(span),
+            help: None,
+            inner: vec![],
+        }),
     }
 }
 
@@ -648,13 +646,13 @@ where
             let res = res.into_series();
             NuDataFrame::series_to_value(res, span)
         }
-        Err(e) => Err(ShellError::GenericError(
-            "Unable to cast to i64".into(),
-            e.to_string(),
-            Some(span),
-            None,
-            Vec::new(),
-        )),
+        Err(e) => Err(ShellError::GenericError {
+            error: "Unable to cast to i64".into(),
+            msg: e.to_string(),
+            span: Some(span),
+            help: None,
+            inner: vec![],
+        }),
     }
 }
 
@@ -671,29 +669,29 @@ where
                     let casted = series.f64();
                     compare_casted_f64(casted, val, f, span)
                 }
-                Err(e) => Err(ShellError::GenericError(
-                    "Unable to cast to i64".into(),
-                    e.to_string(),
-                    Some(span),
-                    None,
-                    Vec::new(),
-                )),
+                Err(e) => Err(ShellError::GenericError {
+                    error: "Unable to cast to i64".into(),
+                    msg: e.to_string(),
+                    span: Some(span),
+                    help: None,
+                    inner: vec![],
+                }),
             }
         }
         DataType::Float64 => {
             let casted = series.f64();
             compare_casted_f64(casted, val, f, span)
         }
-        _ => Err(ShellError::GenericError(
-            "Incorrect type".into(),
-            format!(
+        _ => Err(ShellError::GenericError {
+            error: "Incorrect type".into(),
+            msg: format!(
                 "Series of type {} can not be used for operations with a float value",
                 series.dtype()
             ),
-            Some(span),
-            None,
-            Vec::new(),
-        )),
+            span: Some(span),
+            help: None,
+            inner: vec![],
+        }),
     }
 }
 
@@ -712,13 +710,13 @@ where
             let res = res.into_series();
             NuDataFrame::series_to_value(res, span)
         }
-        Err(e) => Err(ShellError::GenericError(
-            "Unable to cast to f64".into(),
-            e.to_string(),
-            Some(span),
-            None,
-            Vec::new(),
-        )),
+        Err(e) => Err(ShellError::GenericError {
+            error: "Unable to cast to f64".into(),
+            msg: e.to_string(),
+            span: Some(span),
+            help: None,
+            inner: vec![],
+        }),
     }
 }
 
@@ -733,22 +731,22 @@ fn contains_series_pat(series: &Series, pat: &str, span: Span) -> Result<Value,
                     let res = res.into_series();
                     NuDataFrame::series_to_value(res, span)
                 }
-                Err(e) => Err(ShellError::GenericError(
-                    "Error using contains".into(),
-                    e.to_string(),
-                    Some(span),
-                    None,
-                    Vec::new(),
-                )),
+                Err(e) => Err(ShellError::GenericError {
+                    error: "Error using contains".into(),
+                    msg: e.to_string(),
+                    span: Some(span),
+                    help: None,
+                    inner: vec![],
+                }),
             }
         }
-        Err(e) => Err(ShellError::GenericError(
-            "Unable to cast to string".into(),
-            e.to_string(),
-            Some(span),
-            None,
-            Vec::new(),
-        )),
+        Err(e) => Err(ShellError::GenericError {
+            error: "Unable to cast to string".into(),
+            msg: e.to_string(),
+            span: Some(span),
+            help: None,
+            inner: vec![],
+        }),
     }
 }
 
@@ -761,12 +759,12 @@ fn add_string_to_series(series: &Series, pat: &str, span: Span) -> Result<Value,
 
             NuDataFrame::series_to_value(res, span)
         }
-        Err(e) => Err(ShellError::GenericError(
-            "Unable to cast to string".into(),
-            e.to_string(),
-            Some(span),
-            None,
-            Vec::new(),
-        )),
+        Err(e) => Err(ShellError::GenericError {
+            error: "Unable to cast to string".into(),
+            msg: e.to_string(),
+            span: Some(span),
+            help: None,
+            inner: vec![],
+        }),
     }
 }
