@@ -110,27 +110,27 @@ where
             match shift_result {
                 Ok(val) => Value::int( val, span ),
                 Err(_) => Value::error(
-                    ShellError::GenericError(
-                        "Shift right result beyond the range of 64 bit signed number".to_string(),
-                        format!(
+                    ShellError::GenericError {
+                        error: "Shift right result beyond the range of 64 bit signed number".into(),
+                        msg: format!(
                             "{val} of the specified number of bytes shift right {bits} bits exceed limit"
                         ),
-                        Some(span),
-                        None,
-                        Vec::new(),
-                    ),
+                        span: Some(span),
+                        help: None,
+                        inner: vec![],
+                    },
                     span,
                 ),
             }
         }
         None => Value::error(
-            ShellError::GenericError(
-                "Shift right failed".to_string(),
-                format!("{val} shift right {bits} bits failed, you may shift too many bits"),
-                Some(span),
-                None,
-                Vec::new(),
-            ),
+            ShellError::GenericError {
+                error: "Shift right failed".into(),
+                msg: format!("{val} shift right {bits} bits failed, you may shift too many bits"),
+                span: Some(span),
+                help: None,
+                inner: vec![],
+            },
             span,
         ),
     }
