@@ -2,8 +2,8 @@ use nu_engine::{eval_block, CallExt};
 use nu_protocol::ast::{Block, Call};
 use nu_protocol::engine::{Closure, Command, EngineState, Stack};
 use nu_protocol::{
-    Category, Example, IntoInterruptiblePipelineData, IntoPipelineData, PipelineData,
-    PipelineIterator, Record, ShellError, Signature, Span, SyntaxShape, Type, Value,
+    record, Category, Example, IntoInterruptiblePipelineData, IntoPipelineData, PipelineData,
+    PipelineIterator, ShellError, Signature, Span, SyntaxShape, Type, Value,
 };
 use std::collections::HashSet;
 use std::iter::FromIterator;
@@ -51,29 +51,15 @@ impl Command for UpdateCells {
             $value
           }
     }"#,
-                result: Some(Value::list(
-                    vec![Value::test_record(Record {
-                        cols: vec![
-                            "2021-04-16".into(),
-                            "2021-06-10".into(),
-                            "2021-09-18".into(),
-                            "2021-10-15".into(),
-                            "2021-11-16".into(),
-                            "2021-11-17".into(),
-                            "2021-11-18".into(),
-                        ],
-                        vals: vec![
-                            Value::test_int(37),
-                            Value::test_string(""),
-                            Value::test_string(""),
-                            Value::test_string(""),
-                            Value::test_int(37),
-                            Value::test_string(""),
-                            Value::test_string(""),
-                        ],
-                    })],
-                    Span::test_data(),
-                )),
+                result: Some(Value::test_list(vec![Value::test_record(record! {
+                    "2021-04-16" => Value::test_int(37),
+                    "2021-06-10" => Value::test_string(""),
+                    "2021-09-18" => Value::test_string(""),
+                    "2021-10-15" => Value::test_string(""),
+                    "2021-11-16" => Value::test_int(37),
+                    "2021-11-17" => Value::test_string(""),
+                    "2021-11-18" => Value::test_string(""),
+                })])),
             },
             Example {
                 description: "Update the zero value cells to empty strings in 2 last columns.",
@@ -87,29 +73,15 @@ impl Command for UpdateCells {
               $value
             }
     }"#,
-                result: Some(Value::list(
-                    vec![Value::test_record(Record {
-                        cols: vec![
-                            "2021-04-16".into(),
-                            "2021-06-10".into(),
-                            "2021-09-18".into(),
-                            "2021-10-15".into(),
-                            "2021-11-16".into(),
-                            "2021-11-17".into(),
-                            "2021-11-18".into(),
-                        ],
-                        vals: vec![
-                            Value::test_int(37),
-                            Value::test_int(0),
-                            Value::test_int(0),
-                            Value::test_int(0),
-                            Value::test_int(37),
-                            Value::test_string(""),
-                            Value::test_string(""),
-                        ],
-                    })],
-                    Span::test_data(),
-                )),
+                result: Some(Value::test_list(vec![Value::test_record(record! {
+                    "2021-04-16" => Value::test_int(37),
+                    "2021-06-10" => Value::test_int(0),
+                    "2021-09-18" => Value::test_int(0),
+                    "2021-10-15" => Value::test_int(0),
+                    "2021-11-16" => Value::test_int(37),
+                    "2021-11-17" => Value::test_string(""),
+                    "2021-11-18" => Value::test_string(""),
+                })])),
             },
         ]
     }
@@ -124,7 +96,7 @@ impl Command for UpdateCells {
         // the block to run on each cell
         let engine_state = engine_state.clone();
         let block: Closure = call.req(&engine_state, stack, 0)?;
-        let mut stack = stack.captures_to_stack(&block.captures);
+        let mut stack = stack.captures_to_stack(block.captures);
         let orig_env_vars = stack.env_vars.clone();
         let orig_env_hidden = stack.env_hidden.clone();
 
@@ -186,7 +158,7 @@ impl Iterator for UpdateCellIterator {
         match self.input.next() {
             Some(val) => {
                 if let Some(ref cols) = self.columns {
-                    if !val.columns().iter().any(|c| cols.contains(c)) {
+                    if !val.columns().any(|c| cols.contains(c)) {
                         return Some(val);
                     }
                 }
