@@ -304,13 +304,13 @@ fn to_html(
         let color_hm = match color_hm {
             Ok(c) => c,
             _ => {
-                return Err(ShellError::GenericError(
-                    "Error finding theme name".to_string(),
-                    "Error finding theme name".to_string(),
-                    Some(theme_span),
-                    None,
-                    Vec::new(),
-                ))
+                return Err(ShellError::GenericError {
+                    error: "Error finding theme name".into(),
+                    msg: "Error finding theme name".into(),
+                    span: Some(theme_span),
+                    help: None,
+                    inner: vec![],
+                })
             }
         };
 
