@@ -21,7 +21,7 @@ impl Command for Loop {
         Signature::build("loop")
             .input_output_types(vec![(Type::Nothing, Type::Nothing)])
             .allow_variants_without_examples(true)
-            .required("block", SyntaxShape::Block, "block to loop")
+            .required("block", SyntaxShape::Block, "Block to loop.")
             .category(Category::Core)
     }
 
@@ -48,10 +48,10 @@ impl Command for Loop {
                 call.redirect_stdout,
                 call.redirect_stderr,
             ) {
-                Err(ShellError::Break(_)) => {
+                Err(ShellError::Break { .. }) => {
                     break;
                 }
-                Err(ShellError::Continue(_)) => {
+                Err(ShellError::Continue { .. }) => {
                     continue;
                 }
                 Err(err) => {
