@@ -41,12 +41,12 @@ impl Command for BytesIndexOf {
             .required(
                 "pattern",
                 SyntaxShape::Binary,
-                "the pattern to find index of",
+                "The pattern to find index of.",
             )
             .rest(
                 "rest",
                 SyntaxShape::CellPath,
-                "for a data structure input, find the indexes at the given cell paths",
+                "For a data structure input, find the indexes at the given cell paths.",
             )
             .switch("all", "returns all matched index", Some('a'))
             .switch("end", "search from the end of the binary", Some('e'))
