@@ -25,8 +25,8 @@ impl Command for Histogram {
     fn signature(&self) -> Signature {
         Signature::build("histogram")
             .input_output_types(vec![(Type::List(Box::new(Type::Any)), Type::Table(vec![])),])
-            .optional("column-name", SyntaxShape::String, "column name to calc frequency, no need to provide if input is just a list")
-            .optional("frequency-column-name", SyntaxShape::String, "histogram's frequency column, default to be frequency column output")
+            .optional("column-name", SyntaxShape::String, "Column name to calc frequency, no need to provide if input is a list.")
+            .optional("frequency-column-name", SyntaxShape::String, "Histogram's frequency column, default to be frequency column output.")
             .named("percentage-type", SyntaxShape::String, "percentage calculate method, can be 'normalize' or 'relative', in 'normalize', defaults to be 'normalize'", Some('t'))
             .category(Category::Chart)
     }
@@ -258,16 +258,16 @@ fn histogram_impl(
         result.push((
             count, // attach count first for easily sorting.
             Value::record(
-                Record {
-                    cols: result_cols.clone(),
-                    vals: vec![
+                Record::from_raw_cols_vals(
+                    result_cols.clone(),
+                    vec![
                         val.into_value(),
                         Value::int(count, span),
                         Value::float(quantile, span),
                         Value::string(percentage, span),
                         Value::string(freq, span),
                     ],
-                },
+                ),
                 span,
             ),
         ));
