@@ -169,7 +169,6 @@ pub fn add_shell_command_context(mut engine_state: EngineState) -> EngineState {
             EncodeBase64,
             DetectColumns,
             Parse,
-            Size,
             Split,
             SplitChars,
             SplitColumn,
@@ -192,6 +191,7 @@ pub fn add_shell_command_context(mut engine_state: EngineState) -> EngineState {
             StrSubstring,
             StrTrim,
             StrUpcase,
+            Format,
             FormatDate,
             FormatDuration,
             FormatFilesize,
@@ -202,7 +202,8 @@ pub fn add_shell_command_context(mut engine_state: EngineState) -> EngineState {
             Cd,
             Ls,
             Mkdir,
-        UMkdir,
+            UMkdir,
+            Mktemp,
             Mv,
             Cp,
             UCp,
@@ -225,12 +226,16 @@ pub fn add_shell_command_context(mut engine_state: EngineState) -> EngineState {
             Input,
             InputList,
             InputListen,
+            IsTerminal,
             Kill,
             Sleep,
             TermSize,
             Whoami,
         };
 
+        #[cfg(unix)]
+        bind_command! { ULimit };
+
         // Date
         bind_command! {
             Date,
@@ -382,7 +387,6 @@ pub fn add_shell_command_context(mut engine_state: EngineState) -> EngineState {
             Seq,
             SeqDate,
             SeqChar,
-            Unfold, // deprecated
             Generate,
         };
 
@@ -404,6 +408,20 @@ pub fn add_shell_command_context(mut engine_state: EngineState) -> EngineState {
             DateFormat,
         };
 
+        // Stor
+        #[cfg(feature = "sqlite")]
+        bind_command! {
+            Stor,
+            StorCreate,
+            StorDelete,
+            StorExport,
+            StorImport,
+            StorInsert,
+            StorOpen,
+            StorReset,
+            StorUpdate,
+        };
+
         working_set.render()
     };
 
