@@ -68,13 +68,13 @@ impl Command for ConfigEnv {
         let nu_config = match engine_state.get_config_path("env-path") {
             Some(path) => path.clone(),
             None => {
-                return Err(ShellError::GenericError(
-                    "Could not find $nu.env-path".to_string(),
-                    "Could not find $nu.env-path".to_string(),
-                    None,
-                    None,
-                    Vec::new(),
-                ));
+                return Err(ShellError::GenericError {
+                    error: "Could not find $nu.env-path".into(),
+                    msg: "Could not find $nu.env-path".into(),
+                    span: None,
+                    help: None,
+                    inner: vec![],
+                });
             }
         };
 
