@@ -51,13 +51,13 @@ impl Command for ConfigReset {
         let mut config_path = match nu_path::config_dir() {
             Some(path) => path,
             None => {
-                return Err(ShellError::GenericError(
-                    "Could not find config path".to_string(),
-                    "Could not find config path".to_string(),
-                    None,
-                    None,
-                    Vec::new(),
-                ));
+                return Err(ShellError::GenericError {
+                    error: "Could not find config path".into(),
+                    msg: "Could not find config path".into(),
+                    span: None,
+                    help: None,
+                    inner: vec![],
+                });
             }
         };
         config_path.push("nushell");
@@ -72,18 +72,18 @@ impl Command for ConfigReset {
                     Local::now().format("%F-%H-%M-%S"),
                 ));
                 if std::fs::rename(nu_config.clone(), backup_path).is_err() {
-                    return Err(ShellError::FileNotFoundCustom(
-                        "config.nu could not be backed up".into(),
+                    return Err(ShellError::FileNotFoundCustom {
+                        msg: "config.nu could not be backed up".into(),
                         span,
-                    ));
+                    });
                 }
             }
             if let Ok(mut file) = std::fs::File::create(nu_config) {
                 if writeln!(&mut file, "{config_file}").is_err() {
-                    return Err(ShellError::FileNotFoundCustom(
-                        "config.nu could not be written to".into(),
+                    return Err(ShellError::FileNotFoundCustom {
+                        msg: "config.nu could not be written to".into(),
                         span,
-                    ));
+                    });
                 }
             }
         }
@@ -95,18 +95,18 @@ impl Command for ConfigReset {
                 let mut backup_path = config_path.clone();
                 backup_path.push(format!("oldenv-{}.nu", Local::now().format("%F-%H-%M-%S"),));
                 if std::fs::rename(env_config.clone(), backup_path).is_err() {
-                    return Err(ShellError::FileNotFoundCustom(
-                        "env.nu could not be backed up".into(),
+                    return Err(ShellError::FileNotFoundCustom {
+                        msg: "env.nu could not be backed up".into(),
                         span,
-                    ));
+                    });
                 }
             }
             if let Ok(mut file) = std::fs::File::create(env_config) {
                 if writeln!(&mut file, "{config_file}").is_err() {
-                    return Err(ShellError::FileNotFoundCustom(
-                        "env.nu could not be written to".into(),
+                    return Err(ShellError::FileNotFoundCustom {
+                        msg: "env.nu could not be written to".into(),
                         span,
-                    ));
+                    });
                 }
             }
         }
