@@ -1,6 +1,5 @@
 mod config;
 mod export_env;
-mod let_env;
 mod load_env;
 mod source_env;
 mod with_env;
@@ -10,7 +9,6 @@ pub use config::ConfigMeta;
 pub use config::ConfigNu;
 pub use config::ConfigReset;
 pub use export_env::ExportEnv;
-pub use let_env::LetEnv;
 pub use load_env::LoadEnv;
 pub use source_env::SourceEnv;
 pub use with_env::WithEnv;
