@@ -3,6 +3,7 @@ mod cp;
 mod glob;
 mod ls;
 mod mkdir;
+mod mktemp;
 mod mv;
 mod open;
 mod rm;
@@ -20,6 +21,7 @@ pub use cp::Cp;
 pub use glob::Glob;
 pub use ls::Ls;
 pub use mkdir::Mkdir;
+pub use mktemp::Mktemp;
 pub use mv::Mv;
 pub use rm::Rm;
 pub use save::Save;
