@@ -1,10 +1,11 @@
 use nu_engine::{current_dir, eval_block, CallExt};
+use nu_path::expand_to_real_path;
 use nu_protocol::ast::Call;
 use nu_protocol::engine::{Command, EngineState, Stack};
 use nu_protocol::util::BufferedReader;
 use nu_protocol::{
-    Category, Example, IntoInterruptiblePipelineData, PipelineData, RawStream, ShellError,
-    Signature, Spanned, SyntaxShape, Type, Value,
+    Category, DataSource, Example, IntoInterruptiblePipelineData, PipelineData, PipelineMetadata,
+    RawStream, ShellError, Signature, Spanned, SyntaxShape, Type, Value,
 };
 use std::io::BufReader;
 
@@ -41,11 +42,11 @@ impl Command for Open {
     fn signature(&self) -> nu_protocol::Signature {
         Signature::build("open")
             .input_output_types(vec![(Type::Nothing, Type::Any), (Type::String, Type::Any)])
-            .optional("filename", SyntaxShape::Filepath, "the filename to use")
+            .optional("filename", SyntaxShape::Filepath, "The filename to use.")
             .rest(
                 "filenames",
                 SyntaxShape::Filepath,
-                "optional additional files to open",
+                "Optional additional files to open.",
             )
             .switch("raw", "open file as raw binary", Some('r'))
             .category(Category::FileSystem)
@@ -105,7 +106,7 @@ impl Command for Open {
 
             for path in nu_engine::glob_from(&path, &cwd, call_span, None)
                 .map_err(|err| match err {
-                    ShellError::DirectoryNotFound(span, _) => ShellError::FileNotFound(span),
+                    ShellError::DirectoryNotFound { span, .. } => ShellError::FileNotFound { span },
                     _ => err,
                 })?
                 .1
@@ -125,13 +126,13 @@ impl Command for Open {
 
                     #[cfg(not(unix))]
                     let error_msg = String::from("Permission denied");
-                    return Err(ShellError::GenericError(
-                        "Permission denied".into(),
-                        error_msg,
-                        Some(arg_span),
-                        None,
-                        Vec::new(),
-                    ));
+                    return Err(ShellError::GenericError {
+                        error: "Permission denied".into(),
+                        msg: error_msg,
+                        span: Some(arg_span),
+                        help: None,
+                        inner: vec![],
+                    });
                 } else {
                     #[cfg(feature = "sqlite")]
                     if !raw {
@@ -146,17 +147,18 @@ impl Command for Open {
                     let file = match std::fs::File::open(path) {
                         Ok(file) => file,
                         Err(err) => {
-                            return Err(ShellError::GenericError(
-                                "Permission denied".into(),
-                                err.to_string(),
-                                Some(arg_span),
-                                None,
-                                Vec::new(),
-                            ));
+                            return Err(ShellError::GenericError {
+                                error: "Permission denied".into(),
+                                msg: err.to_string(),
+                                span: Some(arg_span),
+                                help: None,
+                                inner: vec![],
+                            });
                         }
                     };
 
                     let buf_reader = BufReader::new(file);
+                    let real_path = expand_to_real_path(path);
 
                     let file_contents = PipelineData::ExternalStream {
                         stdout: Some(RawStream::new(
@@ -168,7 +170,9 @@ impl Command for Open {
                         stderr: None,
                         exit_code: None,
                         span: call_span,
-                        metadata: None,
+                        metadata: Some(PipelineMetadata {
+                            data_source: DataSource::FilePath(real_path),
+                        }),
                         trim_end_newline: false,
                     };
                     let exts_opt: Option<Vec<String>> = if raw {
@@ -200,13 +204,13 @@ impl Command for Open {
                                 decl.run(engine_state, stack, &Call::new(call_span), file_contents)
                             };
                             output.push(command_output.map_err(|inner| {
-                                    ShellError::GenericError(
-                                        format!("Error while parsing as {ext}"),
-                                        format!("Could not parse '{}' with `from {}`", path.display(), ext),
-                                        Some(arg_span),
-                                        Some(format!("Check out `help from {}` or `help from` for more options or open raw data with `open --raw '{}'`", ext, path.display())),
-                                        vec![inner],
-                                    )
+                                    ShellError::GenericError{
+                                        error: format!("Error while parsing as {ext}"),
+                                        msg: format!("Could not parse '{}' with `from {}`", path.display(), ext),
+                                        span: Some(arg_span),
+                                        help: Some(format!("Check out `help from {}` or `help from` for more options or open raw data with `open --raw '{}'`", ext, path.display())),
+                                        inner: vec![inner],
+                                }
                                 })?);
                         }
                         None => output.push(file_contents),
