@@ -25,9 +25,9 @@ impl Command for DropNth {
                 "row number or row range",
                 // FIXME: we can make this accept either Int or Range when we can compose SyntaxShapes
                 SyntaxShape::Any,
-                "the number of the row to drop or a range to drop consecutive rows",
+                "The number of the row to drop or a range to drop consecutive rows.",
             )
-            .rest("rest", SyntaxShape::Any, "the number of the row to drop")
+            .rest("rest", SyntaxShape::Any, "The number of the row to drop.")
             .category(Category::Filters)
     }
 
@@ -104,6 +104,7 @@ impl Command for DropNth {
         call: &Call,
         input: PipelineData,
     ) -> Result<PipelineData, ShellError> {
+        let metadata = input.metadata();
         let number_or_range = extract_int_or_range(engine_state, stack, call)?;
         let mut lower_bound = None;
         let rows = match number_or_range {
@@ -165,14 +166,14 @@ impl Command for DropNth {
                 .into_iter()
                 .take(lower_bound)
                 .collect::<Vec<_>>()
-                .into_pipeline_data(engine_state.ctrlc.clone()))
+                .into_pipeline_data_with_metadata(metadata, engine_state.ctrlc.clone()))
         } else {
             Ok(DropNthIterator {
                 input: input.into_iter(),
                 rows,
                 current: 0,
             }
-            .into_pipeline_data(engine_state.ctrlc.clone()))
+            .into_pipeline_data_with_metadata(metadata, engine_state.ctrlc.clone()))
         }
     }
 }
