@@ -64,7 +64,7 @@ impl Command for Find {
                 Some('c'),
             )
             .switch("invert", "invert the match", Some('v'))
-            .rest("rest", SyntaxShape::Any, "terms to search")
+            .rest("rest", SyntaxShape::Any, "Terms to search.")
             .category(Category::Filters)
     }
 
@@ -304,8 +304,9 @@ fn highlight_terms_in_record_with_search_columns(
         let val_str = val.into_string("", config);
         let Some(term_str) = term_strs
             .iter()
-            .find(|term_str| contains_ignore_case(&val_str, term_str)) else {
-                continue;
+            .find(|term_str| contains_ignore_case(&val_str, term_str))
+        else {
+            continue;
         };
 
         let highlighted_str =
@@ -391,7 +392,7 @@ fn find_with_rest_and_highlight(
                 },
                 ctrlc,
             ),
-        PipelineData::ListStream(stream, meta) => Ok(ListStream::from_stream(
+        PipelineData::ListStream(stream, metadata) => Ok(ListStream::from_stream(
             stream
                 .map(move |mut x| {
                     let span = x.span();
@@ -420,8 +421,7 @@ fn find_with_rest_and_highlight(
                 }),
             ctrlc.clone(),
         )
-        .into_pipeline_data(ctrlc)
-        .set_metadata(meta)),
+        .into_pipeline_data_with_metadata(metadata, ctrlc)),
         PipelineData::ExternalStream { stdout: None, .. } => Ok(PipelineData::empty()),
         PipelineData::ExternalStream {
             stdout: Some(stream),
@@ -516,7 +516,6 @@ fn value_should_be_printed(
             Err(_) => false,
         },
         Value::Binary { .. } => false,
-        Value::MatchPattern { .. } => false,
     });
     if invert {
         match_found = !match_found;
@@ -582,8 +581,7 @@ fn split_string_if_multiline(input: PipelineData, head_span: Span) -> PipelineDa
                         .collect(),
                     span,
                 )
-                .into_pipeline_data()
-                .set_metadata(input.metadata())
+                .into_pipeline_data_with_metadata(input.metadata())
             } else {
                 input
             }
