@@ -22,7 +22,7 @@ impl Command for Items {
             .required(
                 "closure",
                 SyntaxShape::Closure(Some(vec![SyntaxShape::Any, SyntaxShape::Any])),
-                "the closure to run",
+                "The closure to run.",
             )
             .allow_variants_without_examples(true)
             .category(Category::Filters)
@@ -83,7 +83,7 @@ impl Command for Items {
                 redirect_stderr,
             ) {
                 Ok(v) => Some(v.into_value(span)),
-                Err(ShellError::Break(_)) => None,
+                Err(ShellError::Break { .. }) => None,
                 Err(error) => {
                     let error = chain_error_with_input(error, false, input_span);
                     Some(Value::error(error, span))
