@@ -2,16 +2,15 @@ use nu_engine::CallExt;
 use nu_protocol::ast::Call;
 use nu_protocol::engine::{Command, EngineState, Stack};
 use nu_protocol::{
-    Category, Example, PipelineData, ShellError, Signature, SyntaxShape, Type, Value,
+    Category, Example, PipelineData, ShellError, Signature, Spanned, SyntaxShape, Type, Value,
 };
 
 use crate::network::http::client::{
-    http_client, http_parse_url, request_add_authorization_header, request_add_custom_headers,
-    request_handle_response, request_set_timeout, send_request,
+    check_response_redirection, http_client, http_parse_redirect_mode, http_parse_url,
+    request_add_authorization_header, request_add_custom_headers, request_handle_response,
+    request_set_timeout, send_request, RequestFlags,
 };
 
-use super::client::RequestFlags;
-
 #[derive(Clone)]
 pub struct SubCommand;
 
@@ -27,7 +26,7 @@ impl Command for SubCommand {
             .required(
                 "URL",
                 SyntaxShape::String,
-                "the URL to fetch the contents from",
+                "The URL to fetch the contents from.",
             )
             .named(
                 "user",
@@ -73,6 +72,12 @@ impl Command for SubCommand {
                 "do not fail if the server returns an error code",
                 Some('e'),
             )
+            .named(
+                "redirect-mode",
+                SyntaxShape::String,
+                "What to do when encountering redirects. Default: 'follow'. Valid options: 'follow' ('f'), 'manual' ('m'), 'error' ('e').",
+                Some('R')
+            )
             .filter()
             .category(Category::Network)
     }
@@ -137,6 +142,7 @@ struct Arguments {
     timeout: Option<Value>,
     full: bool,
     allow_errors: bool,
+    redirect: Option<Spanned<String>>,
 }
 
 fn run_get(
@@ -155,6 +161,7 @@ fn run_get(
         timeout: call.get_flag(engine_state, stack, "max-time")?,
         full: call.has_flag("full"),
         allow_errors: call.has_flag("allow-errors"),
+        redirect: call.get_flag(engine_state, stack, "redirect-mode")?,
     };
     helper(engine_state, stack, call, args)
 }
@@ -170,8 +177,9 @@ fn helper(
     let span = args.url.span();
     let ctrl_c = engine_state.ctrlc.clone();
     let (requested_url, _) = http_parse_url(call, span, args.url)?;
+    let redirect_mode = http_parse_redirect_mode(args.redirect)?;
 
-    let client = http_client(args.insecure, engine_state, stack);
+    let client = http_client(args.insecure, redirect_mode, engine_state, stack)?;
     let mut request = client.get(&requested_url);
 
     request = request_set_timeout(args.timeout, request)?;
@@ -186,6 +194,7 @@ fn helper(
         allow_errors: args.allow_errors,
     };
 
+    check_response_redirection(redirect_mode, span, &response)?;
     request_handle_response(
         engine_state,
         stack,
