@@ -5,12 +5,13 @@ use nu_engine::CallExt;
 use nu_protocol::ast::Call;
 use nu_protocol::engine::{Command, EngineState, Stack};
 use nu_protocol::{
-    Category, Example, PipelineData, ShellError, Signature, SyntaxShape, Type, Value,
+    Category, Example, PipelineData, ShellError, Signature, Spanned, SyntaxShape, Type, Value,
 };
 
 use crate::network::http::client::{
-    http_client, http_parse_url, request_add_authorization_header, request_add_custom_headers,
-    request_handle_response_headers, request_set_timeout, send_request,
+    check_response_redirection, http_client, http_parse_redirect_mode, http_parse_url,
+    request_add_authorization_header, request_add_custom_headers, request_handle_response_headers,
+    request_set_timeout, send_request,
 };
 
 #[derive(Clone)]
@@ -28,7 +29,7 @@ impl Command for SubCommand {
             .required(
                 "URL",
                 SyntaxShape::String,
-                "the URL to fetch the contents from",
+                "The URL to fetch the contents from.",
             )
             .named(
                 "user",
@@ -58,6 +59,11 @@ impl Command for SubCommand {
                 "insecure",
                 "allow insecure server connections when using SSL",
                 Some('k'),
+            ).named(
+                "redirect-mode",
+                SyntaxShape::String,
+                "What to do when encountering redirects. Default: 'follow'. Valid options: 'follow' ('f'), 'manual' ('m'), 'error' ('e').",
+                Some('R')
             )
             .filter()
             .category(Category::Network)
@@ -114,6 +120,7 @@ struct Arguments {
     user: Option<String>,
     password: Option<String>,
     timeout: Option<Value>,
+    redirect: Option<Spanned<String>>,
 }
 
 fn run_head(
@@ -129,6 +136,7 @@ fn run_head(
         user: call.get_flag(engine_state, stack, "user")?,
         password: call.get_flag(engine_state, stack, "password")?,
         timeout: call.get_flag(engine_state, stack, "max-time")?,
+        redirect: call.get_flag(engine_state, stack, "redirect-mode")?,
     };
     let ctrl_c = engine_state.ctrlc.clone();
 
@@ -146,8 +154,9 @@ fn helper(
 ) -> Result<PipelineData, ShellError> {
     let span = args.url.span();
     let (requested_url, _) = http_parse_url(call, span, args.url)?;
+    let redirect_mode = http_parse_redirect_mode(args.redirect)?;
 
-    let client = http_client(args.insecure, engine_state, stack);
+    let client = http_client(args.insecure, redirect_mode, engine_state, stack)?;
     let mut request = client.head(&requested_url);
 
     request = request_set_timeout(args.timeout, request)?;
@@ -155,6 +164,7 @@ fn helper(
     request = request_add_custom_headers(args.headers, request)?;
 
     let response = send_request(request, None, None, ctrlc);
+    check_response_redirection(redirect_mode, span, &response)?;
     request_handle_response_headers(span, response)
 }
 
