@@ -1,4 +1,5 @@
 mod build_query;
+mod decode;
 mod encode;
 mod join;
 mod parse;
@@ -8,6 +9,7 @@ use url::{self};
 
 pub use self::parse::SubCommand as UrlParse;
 pub use build_query::SubCommand as UrlBuildQuery;
+pub use decode::SubCommand as UrlDecode;
 pub use encode::SubCommand as UrlEncode;
 pub use join::SubCommand as UrlJoin;
 pub use url_::Url;
