@@ -39,7 +39,7 @@ impl Command for Input {
                 (Type::Nothing, Type::Binary),
             ])
             .allow_variants_without_examples(true)
-            .optional("prompt", SyntaxShape::String, "prompt to show the user")
+            .optional("prompt", SyntaxShape::String, "Prompt to show the user.")
             .named(
                 "bytes-until-any",
                 SyntaxShape::String,
@@ -110,7 +110,9 @@ impl Command for Input {
                                 {
                                     if k.modifiers == KeyModifiers::CONTROL && c == 'c' {
                                         crossterm::terminal::disable_raw_mode()?;
-                                        return Err(ShellError::IOError("SIGINT".to_string()));
+                                        return Err(ShellError::IOError {
+                                            msg: "SIGINT".to_string(),
+                                        });
                                     }
                                     continue;
                                 }
