@@ -3,9 +3,12 @@ mod clear;
 mod dir_info;
 mod du;
 mod input;
+mod is_terminal;
 mod kill;
 mod sleep;
 mod term_size;
+#[cfg(unix)]
+mod ulimit;
 mod whoami;
 
 pub use ansi::{Ansi, AnsiLink, AnsiStrip};
@@ -15,7 +18,10 @@ pub use du::Du;
 pub use input::Input;
 pub use input::InputList;
 pub use input::InputListen;
+pub use is_terminal::IsTerminal;
 pub use kill::Kill;
 pub use sleep::Sleep;
 pub use term_size::TermSize;
+#[cfg(unix)]
+pub use ulimit::ULimit;
 pub use whoami::Whoami;
