@@ -14,11 +14,11 @@ impl Command for LetEnv {
         Signature::build(self.name())
             .input_output_types(vec![(Type::Nothing, Type::Nothing)])
             .allow_variants_without_examples(true)
-            .optional("var_name", SyntaxShape::String, "variable name")
+            .optional("var_name", SyntaxShape::String, "Variable name.")
             .optional(
                 "initial_value",
                 SyntaxShape::Keyword(b"=".to_vec(), Box::new(SyntaxShape::MathExpression)),
-                "equals sign followed by value",
+                "Equals sign followed by value.",
             )
             .category(Category::Removed)
     }
@@ -34,10 +34,10 @@ impl Command for LetEnv {
         call: &Call,
         _: PipelineData,
     ) -> Result<PipelineData, ShellError> {
-        Err(nu_protocol::ShellError::RemovedCommand(
-            self.name().to_string(),
-            "$env.<environment variable> = ...".to_owned(),
-            call.head,
-        ))
+        Err(nu_protocol::ShellError::RemovedCommand {
+            removed: self.name().to_string(),
+            replacement: "$env.<environment variable> = ...".to_owned(),
+            span: call.head,
+        })
     }
 }
