@@ -44,7 +44,7 @@ impl Command for DecodeBase64 {
             .rest(
                 "rest",
                 SyntaxShape::CellPath,
-                "For a data structure input, decode data at the given cell paths",
+                "For a data structure input, decode data at the given cell paths.",
             )
             .category(Category::Hash)
     }
