@@ -1,16 +1,16 @@
 mod char_;
 mod detect_columns;
 mod encode_decode;
+mod format;
 mod parse;
-mod size;
 mod split;
 mod str_;
 
 pub use char_::Char;
 pub use detect_columns::*;
 pub use encode_decode::*;
+pub use format::*;
 pub use parse::*;
-pub use size::Size;
 pub use split::*;
 pub use str_::*;
 
