@@ -49,7 +49,7 @@ impl Command for SubCommand {
             .rest(
                 "rest",
                 SyntaxShape::CellPath,
-                "For a data structure input, replace strings at the given cell paths with their length",
+                "For a data structure input, replace strings at the given cell paths with their length.",
             )
             .category(Category::Strings)
     }
