@@ -1,8 +1,9 @@
 use nu_cmd_base::hook::eval_hook;
 use nu_engine::env_to_strings;
+use nu_engine::eval_expression;
 use nu_engine::CallExt;
 use nu_protocol::{
-    ast::{Call, Expr, Expression},
+    ast::{Call, Expr},
     did_you_mean,
     engine::{Command, EngineState, Stack},
     Category, Example, ListStream, PipelineData, RawStream, ShellError, Signature, Span, Spanned,
@@ -47,8 +48,8 @@ impl Command for External {
                 None,
             )
             .switch("trim-end-newline", "trimming end newlines", None)
-            .required("command", SyntaxShape::String, "external command to run")
-            .rest("args", SyntaxShape::Any, "arguments for external command")
+            .required("command", SyntaxShape::String, "External command to run.")
+            .rest("args", SyntaxShape::Any, "Arguments for external command.")
             .category(Category::System)
     }
 
@@ -113,7 +114,6 @@ pub fn create_external_command(
     trim_end_newline: bool,
 ) -> Result<ExternalCommand, ShellError> {
     let name: Spanned<String> = call.req(engine_state, stack, 0)?;
-    let args: Vec<Value> = call.rest(engine_state, stack, 1)?;
 
     // Translate environment variables from Values to Strings
     let env_vars_str = env_to_strings(engine_state, stack)?;
@@ -132,11 +132,24 @@ pub fn create_external_command(
     }
 
     let mut spanned_args = vec![];
-    let args_expr: Vec<Expression> = call.positional_iter().skip(1).cloned().collect();
     let mut arg_keep_raw = vec![];
-    for (one_arg, one_arg_expr) in args.into_iter().zip(args_expr) {
-        match one_arg {
+    for (arg, spread) in call.rest_iter(1) {
+        // TODO: Disallow automatic spreading entirely later. This match block will
+        // have to be refactored, and lists will have to be disallowed in the parser too
+        match eval_expression(engine_state, stack, arg)? {
             Value::List { vals, .. } => {
+                if !spread {
+                    nu_protocol::report_error_new(
+                        engine_state,
+                        &ShellError::GenericError {
+                            error: "Automatically spreading lists is deprecated".into(),
+                            msg: "Spreading lists automatically when calling external commands is deprecated and will be removed in 0.91.".into(),
+                            span: Some(arg.span),
+                            help: Some("Use the spread operator (put a '...' before the argument)".into()),
+                            inner: vec![],
+                        },
+                    );
+                }
                 // turn all the strings in the array into params.
                 // Example: one_arg may be something like ["ls" "-a"]
                 // convert it to "ls" "-a"
@@ -147,15 +160,20 @@ pub fn create_external_command(
                 }
             }
             val => {
-                spanned_args.push(value_as_spanned(val)?);
-                match one_arg_expr.expr {
-                    // refer to `parse_dollar_expr` function
-                    // the expression type of $variable_name, $"($variable_name)"
-                    // will be Expr::StringInterpolation, Expr::FullCellPath
-                    Expr::StringInterpolation(_) | Expr::FullCellPath(_) => arg_keep_raw.push(true),
-                    _ => arg_keep_raw.push(false),
+                if spread {
+                    return Err(ShellError::CannotSpreadAsList { span: arg.span });
+                } else {
+                    spanned_args.push(value_as_spanned(val)?);
+                    match arg.expr {
+                        // refer to `parse_dollar_expr` function
+                        // the expression type of $variable_name, $"($variable_name)"
+                        // will be Expr::StringInterpolation, Expr::FullCellPath
+                        Expr::StringInterpolation(_) | Expr::FullCellPath(_) => {
+                            arg_keep_raw.push(true)
+                        }
+                        _ => arg_keep_raw.push(false),
+                    }
                 }
-                {}
             }
         }
     }
@@ -305,11 +323,11 @@ impl ExternalCommand {
                                 Some(s) => s.clone(),
                                 None => "".to_string(),
                             };
-                            return Err(ShellError::RemovedCommand(
-                                command_name_lower,
+                            return Err(ShellError::RemovedCommand {
+                                removed: command_name_lower,
                                 replacement,
-                                self.name.span,
-                            ));
+                                span: self.name.span,
+                            });
                         }
 
                         let suggestion = suggest_command(&self.name.item, engine_state);
@@ -601,16 +619,16 @@ impl ExternalCommand {
             }
             process
         } else {
-            return Err(ShellError::GenericError(
-                "Current directory not found".to_string(),
-                "did not find PWD environment variable".to_string(),
-                Some(span),
-                Some(concat!(
+            return Err(ShellError::GenericError{
+                error: "Current directory not found".into(),
+                msg: "did not find PWD environment variable".into(),
+                span: Some(span),
+                help: Some(concat!(
                     "The environment variable 'PWD' was not found. ",
                     "It is required to define the current directory when running an external command."
-                ).to_string()),
-                Vec::new(),
-            ));
+                ).into()),
+                inner:Vec::new(),
+            });
         };
 
         process.envs(&self.env_vars);
@@ -927,9 +945,9 @@ mod test {
 
     #[test]
     fn argument_with_inner_quotes_test() {
-        let input = r#"bash -c 'echo a'"#.into();
+        let input = r#"sh -c 'echo a'"#.into();
         let res = remove_quotes(input);
 
-        assert_eq!("bash -c 'echo a'", res)
+        assert_eq!("sh -c 'echo a'", res)
     }
 }
