@@ -1,14 +1,18 @@
+// todo: (refactoring) limit get_config() usage to 1 call
+//        overall reduce the redundant calls to StyleComputer etc.
+//        the goal is to configure it once...
+
 use lscolors::{LsColors, Style};
 use nu_color_config::color_from_hex;
 use nu_color_config::{StyleComputer, TextStyle};
 use nu_engine::{env::get_config, env_to_string, CallExt};
-use nu_protocol::record;
 use nu_protocol::{
     ast::Call,
     engine::{Command, EngineState, Stack},
     Category, Config, DataSource, Example, IntoPipelineData, ListStream, PipelineData,
     PipelineMetadata, RawStream, Record, ShellError, Signature, Span, SyntaxShape, Type, Value,
 };
+use nu_protocol::{record, TableMode};
 use nu_table::common::create_nu_table_config;
 use nu_table::{
     CollapsedTable, ExpandedTable, JustTable, NuTable, NuTableCell, StringResult, TableOpts,
@@ -16,6 +20,7 @@ use nu_table::{
 };
 use nu_utils::get_ls_colors;
 use std::io::IsTerminal;
+use std::str::FromStr;
 use std::sync::Arc;
 use std::time::Instant;
 use std::{path::PathBuf, sync::atomic::AtomicBool};
@@ -60,12 +65,17 @@ impl Command for Table {
             .input_output_types(vec![(Type::Any, Type::Any)])
             // TODO: make this more precise: what turns into string and what into raw stream
             .named(
-                "start-number",
-                SyntaxShape::Int,
-                "row number to start viewing from",
-                Some('n'),
+                "theme",
+                SyntaxShape::String,
+                "set a table mode/theme",
+                Some('t'),
+            )
+            .named(
+                "index",
+                SyntaxShape::Any,
+                "enable (true) or disable (false) the #/index column or set the starting index",
+                Some('i'),
             )
-            .switch("list", "list available table modes/themes", Some('l'))
             .named(
                 "width",
                 SyntaxShape::Int,
@@ -80,7 +90,7 @@ impl Command for Table {
             .named(
                 "expand-deep",
                 SyntaxShape::Int,
-                "an expand limit of recursion which will take place",
+                "an expand limit of recursion which will take place, must be used with --expand",
                 Some('d'),
             )
             .switch("flatten", "Flatten simple arrays", None)
@@ -101,6 +111,7 @@ impl Command for Table {
                 "abbreviate the data in the table by truncating the middle part and only showing amount provided on top and bottom",
                 Some('a'),
             )
+            .switch("list", "list available table modes/themes", Some('l'))
             .category(Category::Viewers)
     }
 
@@ -112,15 +123,15 @@ impl Command for Table {
         input: PipelineData,
     ) -> Result<PipelineData, ShellError> {
         let list_themes: bool = call.has_flag("list");
-        let cfg = parse_table_config(call, engine_state, stack)?;
-        let input = CmdInput::new(engine_state, stack, call, input);
-
         // if list argument is present we just need to return a list of supported table themes
         if list_themes {
             let val = Value::list(supported_table_modes(), Span::test_data());
             return Ok(val.into_pipeline_data());
         }
 
+        let cfg = parse_table_config(call, engine_state, stack)?;
+        let input = CmdInput::new(engine_state, stack, call, input);
+
         // reset vt processing, aka ansi because illbehaved externals can break it
         #[cfg(windows)]
         {
@@ -133,8 +144,8 @@ impl Command for Table {
     fn examples(&self) -> Vec<Example> {
         vec![
             Example {
-                description: "List the files in current directory, with indexes starting from 1.",
-                example: r#"ls | table --start-number 1"#,
+                description: "List the files in current directory, with indexes starting from 1",
+                example: r#"ls | table --index 1"#,
                 result: None,
             },
             Example {
@@ -179,30 +190,54 @@ impl Command for Table {
                     }),
                 ])),
             },
+            Example {
+                description: "Change the table theme to the specified theme for a single run",
+                example: r#"[[a b]; [1 2] [2 [4 4]]] | table --theme basic"#,
+                result: None,
+            },
+            Example {
+                description: "Force showing of the #/index column for a single run",
+                example: r#"[[a b]; [1 2] [2 [4 4]]] | table -i true"#,
+                result: None,
+            },
+            Example {
+                description:
+                    "Set the starting number of the #/index column to 100 for a single run",
+                example: r#"[[a b]; [1 2] [2 [4 4]]] | table -i 100"#,
+                result: None,
+            },
+            Example {
+                description: "Force hiding of the #/index column for a single run",
+                example: r#"[[a b]; [1 2] [2 [4 4]]] | table -i false"#,
+                result: None,
+            },
         ]
     }
 }
 
 #[derive(Debug, Clone)]
 struct TableConfig {
-    row_offset: usize,
+    index: Option<usize>,
     table_view: TableView,
     term_width: usize,
+    theme: TableMode,
     abbreviation: Option<usize>,
 }
 
 impl TableConfig {
     fn new(
-        row_offset: usize,
         table_view: TableView,
         term_width: usize,
+        theme: TableMode,
         abbreviation: Option<usize>,
+        index: Option<usize>,
     ) -> Self {
         Self {
-            row_offset,
+            index,
             table_view,
             term_width,
             abbreviation,
+            theme,
         }
     }
 }
@@ -212,8 +247,6 @@ fn parse_table_config(
     state: &EngineState,
     stack: &mut Stack,
 ) -> Result<TableConfig, ShellError> {
-    let start_num: Option<i64> = call.get_flag(state, stack, "start-number")?;
-    let row_offset = start_num.unwrap_or_default() as usize;
     let width_param: Option<i64> = call.get_flag(state, stack, "width")?;
     let expand: bool = call.has_flag("expand");
     let expand_limit: Option<usize> = call.get_flag(state, stack, "expand-deep")?;
@@ -232,13 +265,74 @@ fn parse_table_config(
             flatten_separator,
         },
     };
+    let theme =
+        get_theme_flag(call, state, stack)?.unwrap_or_else(|| get_config(state, stack).table_mode);
+    let index = get_index_flag(call, state, stack)?;
 
     let term_width = get_width_param(width_param);
-    let cfg = TableConfig::new(row_offset, table_view, term_width, abbrivation);
+    let cfg = TableConfig::new(table_view, term_width, theme, abbrivation, index);
 
     Ok(cfg)
 }
 
+fn get_index_flag(
+    call: &Call,
+    state: &EngineState,
+    stack: &mut Stack,
+) -> Result<Option<usize>, ShellError> {
+    let index: Option<Value> = call.get_flag(state, stack, "index")?;
+    let value = match index {
+        Some(value) => value,
+        None => return Ok(Some(0)),
+    };
+
+    match value {
+        Value::Bool { val, .. } => {
+            if val {
+                Ok(Some(0))
+            } else {
+                Ok(None)
+            }
+        }
+        Value::Int { val, internal_span } => {
+            if val < 0 {
+                Err(ShellError::UnsupportedInput {
+                    msg: String::from("got a negative integer"),
+                    input: val.to_string(),
+                    msg_span: call.span(),
+                    input_span: internal_span,
+                })
+            } else {
+                Ok(Some(val as usize))
+            }
+        }
+        Value::Nothing { .. } => Ok(Some(0)),
+        _ => Err(ShellError::CantConvert {
+            to_type: String::from("index"),
+            from_type: String::new(),
+            span: call.span(),
+            help: Some(String::from("supported values: [bool, int, nothing]")),
+        }),
+    }
+}
+
+fn get_theme_flag(
+    call: &Call,
+    state: &EngineState,
+    stack: &mut Stack,
+) -> Result<Option<TableMode>, ShellError> {
+    call.get_flag(state, stack, "theme")?
+        .map(|theme: String| {
+            TableMode::from_str(&theme).map_err(|err| ShellError::CantConvert {
+                to_type: String::from("theme"),
+                from_type: String::from("string"),
+                span: call.span(),
+                help: Some(format!("{}, but found '{}'.", err, theme)),
+            })
+        })
+        .transpose()
+}
+
 struct CmdInput<'a> {
     engine_state: &'a EngineState,
     stack: &'a mut Stack,
@@ -366,7 +460,17 @@ fn handle_record(
     }
 
     let indent = (config.table_indent.left, config.table_indent.right);
-    let opts = TableOpts::new(&config, styles, ctrlc, span, 0, cfg.term_width, indent);
+    let opts = TableOpts::new(
+        &config,
+        styles,
+        ctrlc,
+        span,
+        cfg.term_width,
+        indent,
+        cfg.theme,
+        cfg.index.unwrap_or(0),
+        cfg.index.is_none(),
+    );
     let result = build_table_kv(record, cfg.table_view, opts, span)?;
 
     let result = match result {
@@ -581,6 +685,7 @@ struct PagingTableCreator {
     elements_displayed: usize,
     reached_end: bool,
     cfg: TableConfig,
+    row_offset: usize,
 }
 
 impl PagingTableCreator {
@@ -601,6 +706,7 @@ impl PagingTableCreator {
             cfg,
             elements_displayed: 0,
             reached_end: false,
+            row_offset: 0,
         }
     }
 
@@ -657,9 +763,11 @@ impl PagingTableCreator {
             style_comp,
             self.ctrlc.clone(),
             self.head,
-            self.cfg.row_offset,
             self.cfg.term_width,
             (cfg.table_indent.left, cfg.table_indent.right),
+            self.cfg.theme,
+            self.cfg.index.unwrap_or(0) + self.row_offset,
+            self.cfg.index.is_none(),
         )
     }
 
@@ -770,7 +878,7 @@ impl Iterator for PagingTableCreator {
 
         let table = self.build_table(batch);
 
-        self.cfg.row_offset += idx;
+        self.row_offset += idx;
 
         let config = get_config(&self.engine_state, &self.stack);
         convert_table_to_output(table, &config, &self.ctrlc, self.cfg.term_width)
@@ -858,7 +966,7 @@ fn create_empty_placeholder(
     let out = TableOutput::new(table, false, false);
 
     let style_computer = &StyleComputer::from_config(engine_state, stack);
-    let config = create_nu_table_config(&config, style_computer, &out, false);
+    let config = create_nu_table_config(&config, style_computer, &out, false, TableMode::default());
 
     out.table
         .draw(config, termwidth)
