@@ -197,7 +197,7 @@ fn def_wrapped_with_block() {
 #[test]
 fn def_wrapped_from_module() {
     let actual = nu!(r#"module spam {
-            export def --wrapped my-echo [...rest] { ^echo $rest }
+            export def --wrapped my-echo [...rest] { nu --testbin cococo ...$rest }
         }
 
         use spam
@@ -299,3 +299,9 @@ fn def_env_wrapped() {
     );
     assert_eq!(actual.out, "bacon");
 }
+
+#[test]
+fn def_env_wrapped_no_help() {
+    let actual = nu!("def --wrapped foo [...rest] { echo $rest }; foo -h | to json --raw");
+    assert_eq!(actual.out, r#"["-h"]"#);
+}
