@@ -7,6 +7,7 @@ mod break_;
 mod cal;
 mod cd;
 mod compact;
+mod complete;
 mod config_env_default;
 mod config_nu_default;
 mod continue_;
@@ -57,6 +58,7 @@ mod match_;
 mod math;
 mod merge;
 mod mkdir;
+mod mktemp;
 mod move_;
 mod mut_;
 mod network;
@@ -99,11 +101,14 @@ mod split_row;
 mod str_;
 mod table;
 mod take;
+mod terminal;
 mod to_text;
 mod touch;
 mod transpose;
 mod try_;
 mod ucp;
+#[cfg(unix)]
+mod ulimit;
 mod umkdir;
 mod uniq;
 mod uniq_by;
