@@ -57,3 +57,9 @@ fn checks_tilde_relative_path_exists() {
     let actual = nu!("'~' | path exists");
     assert_eq!(actual.out, "true");
 }
+
+#[test]
+fn const_path_exists() {
+    let actual = nu!("const exists = ('~' | path exists); $exists");
+    assert_eq!(actual.out, "true");
+}
