@@ -1,33 +1,24 @@
-use nu_test_support::fs::Stub::FileWithContentToBeTrimmed;
-use nu_test_support::playground::Playground;
 use nu_test_support::{nu, pipeline};
 
 #[test]
 fn rows() {
-    Playground::setup("take_test_1", |dirs, sandbox| {
-        sandbox.with_files(vec![FileWithContentToBeTrimmed(
-            "caballeros.csv",
-            r#"
-                name,lucky_code
-                Andrés,1
-                JT,1
-                Jason,2
-                Yehuda,1
-            "#,
-        )]);
+    let sample = r#"
+        [[name,   lucky_code];
+         [Andrés, 1],
+         [JT    , 1],
+         [Jason , 2],
+         [Yehuda, 1]]"#;
 
-        let actual = nu!(
-            cwd: dirs.test(), pipeline(
-            r#"
-                open caballeros.csv
+    let actual = nu!(pipeline(&format!(
+        r#"
+                {sample}
                 | take 3
                 | get lucky_code
                 | math sum
                 "#
-        ));
+    )));
 
-        assert_eq!(actual.out, "4");
-    })
+    assert_eq!(actual.out, "4");
 }
 
 #[test]
