@@ -721,7 +721,7 @@ fn build_table_as_record(v: &RecordView) -> Value {
     let layer = v.get_layer_last();
 
     let cols = layer.columns.to_vec();
-    let vals = layer.records.get(0).map_or(Vec::new(), |row| row.clone());
+    let vals = layer.records.first().map_or(Vec::new(), |row| row.clone());
 
     Value::record(Record::from_raw_cols_vals(cols, vals), NuSpan::unknown())
 }
