@@ -103,6 +103,19 @@ pub struct Paths {
     scope: Option<PathBuf>,
 }
 
+impl Paths {
+    /// An iterator representing a single path.
+    pub fn single(path: &Path, relative_to: &Path) -> Self {
+        Paths {
+            dir_patterns: vec![Pattern::new("*").expect("hard coded pattern")],
+            require_dir: false,
+            options: MatchOptions::default(),
+            todo: vec![Ok((path.to_path_buf(), 0))],
+            scope: Some(relative_to.into()),
+        }
+    }
+}
+
 /// Return an iterator that produces all the `Path`s that match the given
 /// pattern using default match options, which may be absolute or relative to
 /// the current working directory.
@@ -110,7 +123,7 @@ pub struct Paths {
 /// This may return an error if the pattern is invalid.
 ///
 /// This method uses the default match options and is equivalent to calling
-/// `glob_with(pattern, MatchOptions::new())`. Use `glob_with` directly if you
+/// `glob_with(pattern, MatchOptions::default())`. Use `glob_with` directly if you
 /// want to use non-default match options.
 ///
 /// When iterating, each result is a `GlobResult` which expresses the
@@ -273,6 +286,32 @@ pub fn glob_with(pattern: &str, options: MatchOptions) -> Result<Paths, PatternE
     })
 }
 
+/// Return an iterator that produces all the `Path`s that match the given
+/// pattern relative to a specified parent directory and using specified match options.
+/// Paths may be absolute or relative to the current working directory.
+///
+/// This is provided primarily for testability, so multithreaded test runners can
+/// test pattern matches in different test directories at the same time without
+/// having to append the parent to the pattern under test.
+
+pub fn glob_with_parent(
+    pattern: &str,
+    options: MatchOptions,
+    parent: &Path,
+) -> Result<Paths, PatternError> {
+    match glob_with(pattern, options) {
+        Ok(mut p) => {
+            p.scope = match p.scope {
+                None => Some(parent.to_path_buf()),
+                Some(s) if &s.to_string_lossy() == "." => Some(parent.to_path_buf()),
+                Some(s) => Some(s),
+            };
+            Ok(p)
+        }
+        Err(e) => Err(e),
+    }
+}
+
 /// A glob iteration error.
 ///
 /// This is typically returned when a particular path cannot be read
@@ -347,7 +386,10 @@ impl Iterator for Paths {
                 // Shouldn't happen, but we're using -1 as a special index.
                 assert!(self.dir_patterns.len() < !0);
 
-                fill_todo(&mut self.todo, &self.dir_patterns, 0, &scope, self.options);
+                // if there's one prefilled result, take it, otherwise fill the todo buffer
+                if self.todo.len() != 1 {
+                    fill_todo(&mut self.todo, &self.dir_patterns, 0, &scope, self.options);
+                }
             }
         }
 
@@ -704,7 +746,7 @@ impl Pattern {
     }
 
     /// Return if the given `str` matches this `Pattern` using the default
-    /// match options (i.e. `MatchOptions::new()`).
+    /// match options (i.e. `MatchOptions::default()`).
     ///
     /// # Examples
     ///
@@ -720,7 +762,7 @@ impl Pattern {
     }
 
     /// Return if the given `Path`, when converted to a `str`, matches this
-    /// `Pattern` using the default match options (i.e. `MatchOptions::new()`).
+    /// `Pattern` using the default match options (i.e. `MatchOptions::default()`).
     pub fn matches_path(&self, path: &Path) -> bool {
         // FIXME (#9639): This needs to handle non-utf8 paths
         path.to_str().map_or(false, |s| self.matches(s))
@@ -974,29 +1016,19 @@ fn in_char_specifiers(specifiers: &[CharSpecifier], c: char, options: MatchOptio
             CharRange(start, end) => {
                 // FIXME: work with non-ascii chars properly (issue #1347)
                 if !options.case_sensitive && c.is_ascii() && start.is_ascii() && end.is_ascii() {
-                    let start = start.to_ascii_lowercase();
-                    let end = end.to_ascii_lowercase();
-
-                    let start_up = start
-                        .to_uppercase()
-                        .next()
-                        .expect("internal error: getting start uppercase");
-                    let end_up = end
-                        .to_uppercase()
-                        .next()
-                        .expect("internal error: getting end uppercase");
-
                     // only allow case insensitive matching when
                     // both start and end are within a-z or A-Z
-                    if start != start_up && end != end_up {
+                    if start.is_ascii_alphabetic() && end.is_ascii_alphabetic() {
+                        let start = start.to_ascii_lowercase();
+                        let end = end.to_ascii_lowercase();
                         let c = c.to_ascii_lowercase();
-                        if c >= start && c <= end {
+                        if (start..=end).contains(&c) {
                             return true;
                         }
                     }
                 }
 
-                if c >= start && c <= end {
+                if (start..=end).contains(&c) {
                     return true;
                 }
             }
@@ -1237,7 +1269,7 @@ mod test {
     fn test_range_pattern() {
         let pat = Pattern::new("a[0-9]b").unwrap();
         for i in 0..10 {
-            assert!(pat.matches(&format!("a{}b", i)));
+            assert!(pat.matches(&format!("a{}b", i)), "a{i}b =~ a[0-9]b");
         }
         assert!(!pat.matches("a_b"));
 
