@@ -72,6 +72,7 @@ pub struct Config {
     pub datetime_table_format: Option<String>,
     pub error_style: ErrorStyle,
     pub use_kitty_protocol: bool,
+    pub highlight_resolved_externals: bool,
 }
 
 impl Default for Config {
@@ -137,6 +138,7 @@ impl Default for Config {
             error_style: ErrorStyle::Fancy,
 
             use_kitty_protocol: false,
+            highlight_resolved_externals: false,
         }
     }
 }
@@ -622,6 +624,9 @@ impl Value {
                     "use_kitty_protocol" => {
                         process_bool_config(value, &mut errors, &mut config.use_kitty_protocol);
                     }
+                    "highlight_resolved_externals" => {
+                        process_bool_config(value, &mut errors, &mut config.highlight_resolved_externals);
+                    }
                     // Menus
                     "menus" => match create_menus(value) {
                         Ok(map) => config.menus = map,
@@ -700,13 +705,13 @@ impl Value {
         } else {
             return (
                 config,
-                Some(ShellError::GenericError(
-                    "Error while applying config changes".into(),
-                    "$env.config is not a record".into(),
-                    Some(self.span()),
-                    None,
-                    vec![],
-                )),
+                Some(ShellError::GenericError {
+                    error: "Error while applying config changes".into(),
+                    msg: "$env.config is not a record".into(),
+                    span: Some(self.span()),
+                    help: None,
+                    inner: vec![],
+                }),
             );
         }
 
@@ -714,14 +719,13 @@ impl Value {
         (
             config,
             if !errors.is_empty() {
-                Some(ShellError::GenericError(
-                    "Config record contains invalid values or unknown settings".into(),
-                    // Without a span, this second string is ignored.
-                    "".into(),
-                    None,
-                    None,
-                    errors,
-                ))
+                Some(ShellError::GenericError {
+                    error: "Config record contains invalid values or unknown settings".into(),
+                    msg: "".into(),
+                    span: None,
+                    help: None,
+                    inner: errors,
+                })
             } else {
                 None
             },
