@@ -6,7 +6,7 @@ use crate::ast::Block;
 use crate::{
     BlockId, Config, DeclId, FileId, Module, ModuleId, Span, Type, VarId, Variable, VirtualPathId,
 };
-use crate::{Category, ParseError, Value};
+use crate::{Category, ParseError, ParseWarning, Value};
 use core::panic;
 use std::collections::{HashMap, HashSet};
 use std::path::PathBuf;
@@ -27,6 +27,7 @@ pub struct StateWorkingSet<'a> {
     /// Whether or not predeclarations are searched when looking up a command (used with aliases)
     pub search_predecls: bool,
     pub parse_errors: Vec<ParseError>,
+    pub parse_warnings: Vec<ParseWarning>,
 }
 
 impl<'a> StateWorkingSet<'a> {
@@ -39,6 +40,7 @@ impl<'a> StateWorkingSet<'a> {
             parsed_module_files: vec![],
             search_predecls: true,
             parse_errors: vec![],
+            parse_warnings: vec![],
         }
     }
 
@@ -50,6 +52,10 @@ impl<'a> StateWorkingSet<'a> {
         self.parse_errors.push(parse_error)
     }
 
+    pub fn warning(&mut self, parse_warning: ParseWarning) {
+        self.parse_warnings.push(parse_warning)
+    }
+
     pub fn num_files(&self) -> usize {
         self.delta.num_files() + self.permanent_state.num_files()
     }
@@ -317,6 +323,15 @@ impl<'a> StateWorkingSet<'a> {
         self.num_virtual_paths() - 1
     }
 
+    pub fn get_span_for_filename(&self, filename: &str) -> Option<Span> {
+        let (file_id, ..) = self
+            .files()
+            .enumerate()
+            .find(|(_, (fname, _, _))| fname == filename)?;
+
+        Some(self.get_span_for_file(file_id))
+    }
+
     pub fn get_span_for_file(&self, file_id: usize) -> Span {
         let result = self
             .files()
