@@ -24,7 +24,6 @@ pub enum Type {
     Int,
     List(Box<Type>),
     ListStream,
-    MatchPattern,
     #[default]
     Nothing,
     Number,
@@ -110,7 +109,6 @@ impl Type {
             Type::Binary => SyntaxShape::Binary,
             Type::Custom(_) => SyntaxShape::Any,
             Type::Signature => SyntaxShape::Signature,
-            Type::MatchPattern => SyntaxShape::MatchPattern,
         }
     }
 
@@ -131,7 +129,6 @@ impl Type {
             Type::Record(_) => String::from("record"),
             Type::Table(_) => String::from("table"),
             Type::List(_) => String::from("list"),
-            Type::MatchPattern => String::from("match-pattern"),
             Type::Nothing => String::from("nothing"),
             Type::Number => String::from("number"),
             Type::String => String::from("string"),
@@ -198,7 +195,6 @@ impl Display for Type {
             Type::Binary => write!(f, "binary"),
             Type::Custom(custom) => write!(f, "{custom}"),
             Type::Signature => write!(f, "signature"),
-            Type::MatchPattern => write!(f, "match-pattern"),
         }
     }
 }
