@@ -6,8 +6,12 @@ use serde::{Deserialize, Serialize};
 
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct Record {
+    /// Don't use this field publicly!
+    ///
+    /// Only public as command `rename` is not reimplemented in a sane way yet
+    /// Using it or making `vals` public will draw shaming by @sholderbach
     pub cols: Vec<String>,
-    pub vals: Vec<Value>,
+    vals: Vec<Value>,
 }
 
 impl Record {
