@@ -116,7 +116,7 @@ impl Inc {
 
     pub fn inc_value(&self, head: Span, value: &Value) -> Result<Value, LabeledError> {
         match value {
-            Value::Int { val, span } => Ok(Value::int(val + 1, *span)),
+            Value::Int { val, .. } => Ok(Value::int(val + 1, head)),
             Value::String { val, .. } => Ok(self.apply(val, head)),
             x => {
                 let msg = x.as_string().map_err(|e| LabeledError {
