@@ -5,31 +5,25 @@ use pretty_assertions::assert_eq;
 
 #[test]
 fn takes_rows_of_nu_value_strings_and_pipes_it_to_stdin_of_external() {
-    Playground::setup("internal_to_external_pipe_test_1", |dirs, sandbox| {
-        sandbox.with_files(vec![FileWithContentToBeTrimmed(
-            "nu_times.csv",
-            "
-                name,rusty_luck,origin
-                Jason,1,Canada
-                JT,1,New Zealand
-                Andrés,1,Ecuador
-                AndKitKatz,1,Estados Unidos
-            ",
-        )]);
+    let sample = r#"
+                [[name, rusty_luck, origin];
+                 [Jason, 1, Canada],
+                 [JT, 1, "New Zealand"],
+                 [Andrés, 1, Ecuador],
+                 [AndKitKatz, 1, "Estados Unidos"]]
+            "#;
 
-        let actual = nu!(
-        cwd: dirs.test(), pipeline(
+    let actual = nu!(pipeline(&format!(
         "
-            open nu_times.csv
+            {sample}
             | get origin
-            | each { |it| nu --testbin cococo $it | nu --testbin chop }
+            | each {{ |it| nu --testbin cococo $it | nu --testbin chop }}
             | get 2
             "
-        ));
+    )));
 
-        // chop will remove the last escaped double quote from \"Estados Unidos\"
-        assert_eq!(actual.out, "Ecuado");
-    })
+    // chop will remove the last escaped double quote from \"Estados Unidos\"
+    assert_eq!(actual.out, "Ecuado");
 }
 
 #[test]
@@ -111,7 +105,7 @@ fn subexpression_handles_dot() {
         ));
 
         assert_eq!(actual.out, "AndKitKat");
-    })
+    });
 }
 
 #[test]
